@@ -106,7 +106,7 @@ class Storage(driver.Base):
             part_size = self.buffer_size
         
         try:
-            tmp_file = tempfile.mktemp(suffix=path1, prefix=docker_registry_image, dir="/tmp")
+            tmp_file = tempfile.mktemp(suffix=path1, prefix='docker_registry_image', dir="/tmp")
             with open(tmp_file, 'w') as f:
                 while True:
                     buf = fp.read(part_size)
